==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/hdinsight/kotlin/inputs/StorageAccountArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hdinsight.kotlin.inputs

import com.pulumi.azurenative.hdinsight.inputs.StorageAccountArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The storage Account.
 * @property container The container in the storage account, only to be specified for WASB storage accounts.
 * @property fileSystem The filesystem, only to be specified for Azure Data Lake Storage Gen 2.
 * @property fileshare The file share name.
 * @property isDefault Whether or not the storage account is the default storage account.
 * @property key The storage account access key.
 * @property msiResourceId The managed identity (MSI) that is allowed to access the storage account, only to be specified for Azure Data Lake Storage Gen 2.
 * @property name The name of the storage account.
 * @property resourceId The resource ID of storage account, only to be specified for Azure Data Lake Storage Gen 2.
 * @property saskey The shared access signature key.
 */
public data class StorageAccountArgs(
    public val container: Output<String>? = null,
    public val fileSystem: Output<String>? = null,
    public val fileshare: Output<String>? = null,
    public val isDefault: Output<Boolean>? = null,
    public val key: Output<String>? = null,
    public val msiResourceId: Output<String>? = null,
    public val name: Output<String>? = null,
    public val resourceId: Output<String>? = null,
    public val saskey: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hdinsight.inputs.StorageAccountArgs> {
    override fun toJava(): com.pulumi.azurenative.hdinsight.inputs.StorageAccountArgs =
        com.pulumi.azurenative.hdinsight.inputs.StorageAccountArgs.builder()
            .container(container?.applyValue({ args0 -> args0 }))
            .fileSystem(fileSystem?.applyValue({ args0 -> args0 }))
            .fileshare(fileshare?.applyValue({ args0 -> args0 }))
            .isDefault(isDefault?.applyValue({ args0 -> args0 }))
            .key(key?.applyValue({ args0 -> args0 }))
            .msiResourceId(msiResourceId?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .resourceId(resourceId?.applyValue({ args0 -> args0 }))
            .saskey(saskey?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [StorageAccountArgs].
 */
@PulumiTagMarker
public class StorageAccountArgsBuilder internal constructor() {
    private var container: Output<String>? = null

    private var fileSystem: Output<String>? = null

    private var fileshare: Output<String>? = null

    private var isDefault: Output<Boolean>? = null

    private var key: Output<String>? = null

    private var msiResourceId: Output<String>? = null

    private var name: Output<String>? = null

    private var resourceId: Output<String>? = null

    private var saskey: Output<String>? = null

    /**
     * @param value The container in the storage account, only to be specified for WASB storage accounts.
     */
    @JvmName("ovabufvdruejqmpw")
    public suspend fun container(`value`: Output<String>) {
        this.container = value
    }

    /**
     * @param value The filesystem, only to be specified for Azure Data Lake Storage Gen 2.
     */
    @JvmName("hoylgelclqirfmke")
    public suspend fun fileSystem(`value`: Output<String>) {
        this.fileSystem = value
    }

    /**
     * @param value The file share name.
     */
    @JvmName("osughocdufdysuwj")
    public suspend fun fileshare(`value`: Output<String>) {
        this.fileshare = value
    }

    /**
     * @param value Whether or not the storage account is the default storage account.
     */
    @JvmName("qwgmhrsncrwpdlbj")
    public suspend fun isDefault(`value`: Output<Boolean>) {
        this.isDefault = value
    }

    /**
     * @param value The storage account access key.
     */
    @JvmName("gylsiconyxjlsmvs")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The managed identity (MSI) that is allowed to access the storage account, only to be specified for Azure Data Lake Storage Gen 2.
     */
    @JvmName("jumsveokeqgrxyaj")
    public suspend fun msiResourceId(`value`: Output<String>) {
        this.msiResourceId = value
    }

    /**
     * @param value The name of the storage account.
     */
    @JvmName("mwilhyworecllxse")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The resource ID of storage account, only to be specified for Azure Data Lake Storage Gen 2.
     */
    @JvmName("dyjdiasqdfklomot")
    public suspend fun resourceId(`value`: Output<String>) {
        this.resourceId = value
    }

    /**
     * @param value The shared access signature key.
     */
    @JvmName("uhwibjijtcwnghrf")
    public suspend fun saskey(`value`: Output<String>) {
        this.saskey = value
    }

    /**
     * @param value The container in the storage account, only to be specified for WASB storage accounts.
     */
    @JvmName("nkuixxyhfgrohrpm")
    public suspend fun container(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.container = mapped
    }

    /**
     * @param value The filesystem, only to be specified for Azure Data Lake Storage Gen 2.
     */
    @JvmName("irjnoxrpcmvivwlw")
    public suspend fun fileSystem(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileSystem = mapped
    }

    /**
     * @param value The file share name.
     */
    @JvmName("yamcwyhbthoajpkx")
    public suspend fun fileshare(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileshare = mapped
    }

    /**
     * @param value Whether or not the storage account is the default storage account.
     */
    @JvmName("vactoacqorpgmghj")
    public suspend fun isDefault(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isDefault = mapped
    }

    /**
     * @param value The storage account access key.
     */
    @JvmName("qoflvccdivhpvhem")
    public suspend fun key(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value The managed identity (MSI) that is allowed to access the storage account, only to be specified for Azure Data Lake Storage Gen 2.
     */
    @JvmName("qgjuwkrnilrxihmx")
    public suspend fun msiResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.msiResourceId = mapped
    }

    /**
     * @param value The name of the storage account.
     */
    @JvmName("ragpnfcmafssfjfy")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The resource ID of storage account, only to be specified for Azure Data Lake Storage Gen 2.
     */
    @JvmName("ybkkmuaelewtrdks")
    public suspend fun resourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceId = mapped
    }

    /**
     * @param value The shared access signature key.
     */
    @JvmName("ajptimktlhvcergv")
    public suspend fun saskey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.saskey = mapped
    }

    internal fun build(): StorageAccountArgs = StorageAccountArgs(
        container = container,
        fileSystem = fileSystem,
        fileshare = fileshare,
        isDefault = isDefault,
        key = key,
        msiResourceId = msiResourceId,
        name = name,
        resourceId = resourceId,
        saskey = saskey,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/hdinsight/kotlin/inputs/StorageAccountArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hdinsight.kotlin.inputs

import com.pulumi.azurenative.hdinsight.inputs.StorageAccountArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The storage Account.
 * @property container The container in the storage account, only to be specified for WASB storage accounts.
 * @property fileSystem The filesystem, only to be specified for Azure Data Lake Storage Gen 2.
 * @property fileshare The file share name.
 * @property isDefault Whether or not the storage account is the default storage account.
 * @property key The storage account access key.
 * @property msiResourceId The managed identity (MSI) that is allowed to access the storage account, only to be specified for Azure Data Lake Storage Gen 2.
 * @property name The name of the storage account.
 * @property resourceId The resource ID of storage account, only to be specified for Azure Data Lake Storage Gen 2.
 * @property saskey The shared access signature key.
 */
public data class StorageAccountArgs(
    public val container: Output<String>? = null,
    public val fileSystem: Output<String>? = null,
    public val fileshare: Output<String>? = null,
    public val isDefault: Output<Boolean>? = null,
    public val key: Output<String>? = null,
    public val msiResourceId: Output<String>? = null,
    public val name: Output<String>? = null,
    public val resourceId: Output<String>? = null,
    public val saskey: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hdinsight.inputs.StorageAccountArgs> {
    override fun toJava(): com.pulumi.azurenative.hdinsight.inputs.StorageAccountArgs =
        com.pulumi.azurenative.hdinsight.inputs.StorageAccountArgs.builder()
            .container(container?.applyValue({ args0 -> args0 }))
            .fileSystem(fileSystem?.applyValue({ args0 -> args0 }))
            .fileshare(fileshare?.applyValue({ args0 -> args0 }))
            .isDefault(isDefault?.applyValue({ args0 -> args0 }))
            .key(key?.applyValue({ args0 -> args0 }))
            .msiResourceId(msiResourceId?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .resourceId(resourceId?.applyValue({ args0 -> args0 }))
            .saskey(saskey?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [StorageAccountArgs].
 */
@PulumiTagMarker
public class StorageAccountArgsBuilder internal constructor() {
    private var container: Output<String>? = null

    private var fileSystem: Output<String>? = null

    private var fileshare: Output<String>? = null

    private var isDefault: Output<Boolean>? = null

    private var key: Output<String>? = null

    private var msiResourceId: Output<String>? = null

    private var name: Output<String>? = null

    private var resourceId: Output<String>? = null

    private var saskey: Output<String>? = null

    /**
     * @param value The container in the storage account, only to be specified for WASB storage accounts.
     */
    @JvmName("yublpyhvfdegdxct")
    public suspend fun container(`value`: Output<String>) {
        this.container = value
    }

    /**
     * @param value The filesystem, only to be specified for Azure Data Lake Storage Gen 2.
     */
    @JvmName("hrlqqrlaitohvbsi")
    public suspend fun fileSystem(`value`: Output<String>) {
        this.fileSystem = value
    }

    /**
     * @param value The file share name.
     */
    @JvmName("dbpcrgrqmrtwtvxy")
    public suspend fun fileshare(`value`: Output<String>) {
        this.fileshare = value
    }

    /**
     * @param value Whether or not the storage account is the default storage account.
     */
    @JvmName("aoakljdxgmwyoyfw")
    public suspend fun isDefault(`value`: Output<Boolean>) {
        this.isDefault = value
    }

    /**
     * @param value The storage account access key.
     */
    @JvmName("djvufxepbbbpuqtb")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The managed identity (MSI) that is allowed to access the storage account, only to be specified for Azure Data Lake Storage Gen 2.
     */
    @JvmName("vrgchidplmsltlyb")
    public suspend fun msiResourceId(`value`: Output<String>) {
        this.msiResourceId = value
    }

    /**
     * @param value The name of the storage account.
     */
    @JvmName("kvurwksnojsaiphm")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The resource ID of storage account, only to be specified for Azure Data Lake Storage Gen 2.
     */
    @JvmName("yylhleltlwbtnxhw")
    public suspend fun resourceId(`value`: Output<String>) {
        this.resourceId = value
    }

    /**
     * @param value The shared access signature key.
     */
    @JvmName("svekldpvhnesnewu")
    public suspend fun saskey(`value`: Output<String>) {
        this.saskey = value
    }

    /**
     * @param value The container in the storage account, only to be specified for WASB storage accounts.
     */
    @JvmName("iwmpmvbctrfeqxjy")
    public suspend fun container(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.container = mapped
    }

    /**
     * @param value The filesystem, only to be specified for Azure Data Lake Storage Gen 2.
     */
    @JvmName("lsssemimvgsiusso")
    public suspend fun fileSystem(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileSystem = mapped
    }

    /**
     * @param value The file share name.
     */
    @JvmName("prhlimjvbqoroben")
    public suspend fun fileshare(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileshare = mapped
    }

    /**
     * @param value Whether or not the storage account is the default storage account.
     */
    @JvmName("xtxppfojohmievsa")
    public suspend fun isDefault(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isDefault = mapped
    }

    /**
     * @param value The storage account access key.
     */
    @JvmName("chjscagpvvbuydvd")
    public suspend fun key(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value The managed identity (MSI) that is allowed to access the storage account, only to be specified for Azure Data Lake Storage Gen 2.
     */
    @JvmName("yhauoaoowovhxvit")
    public suspend fun msiResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.msiResourceId = mapped
    }

    /**
     * @param value The name of the storage account.
     */
    @JvmName("xupjrtcknwsorgjr")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The resource ID of storage account, only to be specified for Azure Data Lake Storage Gen 2.
     */
    @JvmName("bokhgughugvtgbhm")
    public suspend fun resourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceId = mapped
    }

    /**
     * @param value The shared access signature key.
     */
    @JvmName("xmhpyotttsjugbvq")
    public suspend fun saskey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.saskey = mapped
    }

    internal fun build(): StorageAccountArgs = StorageAccountArgs(
        container = container,
        fileSystem = fileSystem,
        fileshare = fileshare,
        isDefault = isDefault,
        key = key,
        msiResourceId = msiResourceId,
        name = name,
        resourceId = resourceId,
        saskey = saskey,
    )
}
